<?php

/**
 * @file
 * Admin related form(s) etc. for this module.
 */


/**
 * Creates a module settings form.
 *
 * As well as any module settings, this lists what the module knows about node
 * type/product reference fields.
 *
 * @return array
 *   Drupal Form API array.
 */
function commerce_prodnodelink_config_form($form, &$form_state) {
  $form['conf'] = array(
    '#type' => 'fieldset',
    '#title' => t('Configuration'),
    '#collapsible' => TRUE,
    '#collapsed' => FALSE,
    '#tree' => FALSE,
  );

  $form['conf']['commerce_prodnodelink_conf_links_on_ui_product_form'] = array(
    '#type' => 'radios',
    '#title' => t('Display links on the product edit form?'),
    '#default_value' => variable_get('commerce_prodnodelink_conf_links_on_ui_product_form', 1),
    '#options' => array(0 => t('No'), 1 => t('Yes')),
    '#description' => t('Choose whether or not the list of display nodes are
      shown on the product edit form.'),
  );

  $form['data'] = array(
    '#type' => 'fieldset',
    '#title' => t('Data'),
    '#collapsible' => TRUE,
    '#collapsed' => FALSE,
    '#tree' => FALSE,
    '#description' => t('Machine names of node types and their product reference
      field(s).'),
  );

  $node_types = commerce_prodnodelink_product_reference_field_by_node_type();

  foreach ($node_types as $type => $field_data) {
    for ($i = 0, $length = count($field_data); $i < $length; $i++) {
      $suffix = $type . '_' . $field_data[$i]['instance_id'];

      $form['data']['commerce_prodnodelink_data_' . $suffix] = array(
        '#type' => 'textfield',
        '#title' => check_plain($type),
        '#default_value' => variable_get('commerce_prodnodelink_data_' . $suffix, ''),
        '#size' => 25,
        '#maxlength' => 50,
        '#disabled' => TRUE,
        '#required' => TRUE,
      );
    }
  }

  return system_settings_form($form);
}
